@@ -98,14 +98,11 @@ end
 
 -- get configs
 function _get_configs(package, configs)
-
-    -- add prefix
     local configs = configs or {}
     table.insert(configs, "--prefix=" .. _translate_paths(package:installdir()))
 
-    -- add host for cross-complation
-    if not configs.host and package:is_cross() then
-        if package:is_plat("iphoneos", "macosx") then
+    if not configs.host then
+        if package:is_plat("iphoneos", "macosx") and package:is_cross() then
             local triples =
             {
                 arm64  = "aarch64-apple-darwin",
@@ -132,14 +129,14 @@ function _get_configs(package, configs)
                 mips64          = "mips64-linux-android"    -- removed in ndk r17
             }
             table.insert(configs, "--host=" .. (triples[package:arch()] or triples["armeabi-v7a"]))
-        elseif package:is_plat("mingw") then
+        elseif package:is_plat("mingw") then -- we always add host for mingw
             local triples =
             {
                 i386   = "i686-w64-mingw32",
                 x86_64 = "x86_64-w64-mingw32"
             }
             table.insert(configs, "--host=" .. (triples[package:arch()] or triples.i386))
-        elseif package:is_plat("linux") then
+        elseif package:is_plat("linux") and package:is_cross() then
             local triples =
             {
                 ["arm64-v8a"] = "aarch64-linux-gnu",
@@ -165,7 +162,7 @@ function _get_configs(package, configs)
             table.insert(configs, "--host=" .. host)
         end
     end
-    if package:is_plat("linux", "bsd") and
+    if not package:is_plat("windows", "mingw") and
         package:config("pic") ~= false and _has_with_pic(package) then
         table.insert(configs, "--with-pic")
     end
@@ -176,7 +173,7 @@ end
 function _get_cflags_from_packagedeps(package, opt)
     local values
     for _, depname in ipairs(opt.packagedeps) do
-        local dep = type(depname) ~= "string" and depname or package:dep(depname)
+        local dep = type(depname) ~= "string" and depname or package:librarydep(depname)
         if dep then
             local fetchinfo = dep:fetch()
             if fetchinfo then
@@ -208,7 +205,7 @@ end
 function _get_ldflags_from_packagedeps(package, opt)
     local values
     for _, depname in ipairs(opt.packagedeps) do
-        local dep = type(depname) ~= "string" and depname or package:dep(depname)
+        local dep = type(depname) ~= "string" and depname or package:librarydep(depname)
         if dep then
             local fetchinfo = dep:fetch()
             if fetchinfo then
@@ -322,7 +319,7 @@ function buildenvs(package, opt)
         envs.CPP       = package:build_getenv("cpp")
         envs.RANLIB    = package:build_getenv("ranlib")
     end
-    if package:is_plat("linux", "bsd") and
+    if not package:is_plat("windows", "mingw") and
         package:config("pic") ~= false and not _has_with_pic(package) then
         table.insert(cflags, "-fPIC")
         table.insert(cxxflags, "-fPIC")
